raffle.geom Module
=======================

This is a simulated module that holds the following class:

- :class:`raffle.Geom_Rw()`

This class cannot be directly accessed, but the two user-facing classes within it can be.
Within this class, there exist two directly accessible sub-classes:

- :class:`raffle.geom.basis()`
- :class:`raffle.geom.basis_array()`

These are used to handle the geometry of the system, where the former is a single instance of the geometry and the latter is an array of instances.
The documentation for these can be found here: :doc:`raffle.geom_rw_class`.

.. automodule:: raffle.geom
   :members:
   :undoc-members:
   :show-inheritance:
